@@ -91,13 +91,20 @@ class PolicyGroup(Group):
 
 class UtilGroup(Group):
     name        = "util"
-    recipes     = ["apt", "build-essential", "timezone-ii"]
+    recipes     = ["apt", "yum", "build-essential", "rackspace_timezone"]
     priority    = 5
     optional    = False
 
     @classmethod
     def make_attributes(cls, args, ui, tokgen):
-        return {"apt" : {"compile_time_update": True}}
+        return {
+            "apt" : {"compile_time_update": True},
+            "rackspace_timezone": {
+                "config": {
+                    "tz": "UTC"
+                }
+            }
+        }
 
 
 class NtpGroup(Group):
@@ -182,15 +189,12 @@ class AppGroup(Group):
         if urlparse.urlparse(repo).scheme in constant.GIT_NON_SSH_SCHEMES:
             ui.print_fn("You will not need a SSH key for this repository ({0}).".format(repo))
             ssh_key = ""
-            ssh_key_path = ""
         else:
             ssh_key = ui.prompt_ssh_key("Provide a SSH Key for this repository (password-based SSH isn't supported). "
                                         "If this seems wrong, provide a full URL (e.g. file:// ...)")
-            ssh_key_path = os.path.join(os.path.expanduser("~"), "scalr-deploy.pem")
 
         output["scalr"]["deployment"] = {
             "ssh_key": ssh_key,
-            "ssh_key_path": ssh_key_path,
         }
 
         # Endpoint Settings
